Date: 05 13, 2002 10:58:45 AM

# arraylength

## Purpose

Count the number of values in a given variable.

## Syntax

returnedNumber = arraylength(variableName)

returnedNumber - type: int
variableName - type: var

## Returns

## Remarks

Note that the variableName must evaluate to a variable reference (G, S, X, N).

WARNING: arraylength() never returns 0, since every variable is considered to have at least one value. This may yield unexpected behaviors at times.

## Example

## See Also

Parse Tree Functions